import matplotlib.pyplot as plt
import matplotlib as mpl
import numpy as np
from matplotlib.ticker import MultipleLocator, FormatStrFormatter

plt.rcParams['figure.figsize'] = 11, 6.5
minorLocatorx = MultipleLocator(0.02)
minorLocatory = MultipleLocator(0.02)

data_mesa20_2D_gw = np.loadtxt("mesa20_2D_gw.dat",unpack=True)
data_mesa20_2D_pert_gw = np.loadtxt("mesa20_2D_pert_gw.dat",unpack=True)
data_mesa20_3D_gw = np.loadtxt("mesa20_gw.dat",unpack=True)
data_mesa20_3D_pert_gw = np.loadtxt("mesa20_pert_gw.dat",unpack=True)
data_mesa20_3D_pert_LR_gw = np.loadtxt("mesa20_pert_LR_gw.dat",unpack=True)
data_mesa20_3D_LR_gw = np.loadtxt("mesa20_LR_gw.dat",unpack=True)
data_mesa20_3D_v_LR_gw = np.loadtxt("mesa20_v_LR_gw.dat",unpack=True)

xmin=0.0
xmax=0.6
skipn=20
ax1 = plt.subplot(511)
line1, = plt.plot(data_mesa20_2D_gw[0][0::skipn], data_mesa20_2D_gw[9][0::skipn],color='C4',label=r"mesa20_2D") #2D gw in column 10
line2, = plt.plot(data_mesa20_3D_gw[0][0::skipn], data_mesa20_3D_gw[7][0::skipn],color='C0',label=r"mesa20_3D") #3D gw (hplus on equator) in column 8
plt.legend(handles=[line1, line2],frameon=False,labelspacing=3.5,loc=2)
ax1.get_xaxis().set_ticklabels([])
ax1.tick_params(axis='both', labelsize=12)
plt.minorticks_on()
ax1.set_ylim([-45,45])
ax1.set_xlim([xmin,xmax])
ax1.yaxis.set_ticks_position('both')
ax1.xaxis.set_ticks_position('both')

ax2 = plt.subplot(512)
line1, = plt.plot(data_mesa20_2D_pert_gw[0][0::skipn], data_mesa20_2D_pert_gw[9][0::skipn],color='C7',label=r"mesa20_2D_pert",rasterized=False) #2D gw in column 10
line2, = plt.plot(data_mesa20_3D_pert_gw[0][0::skipn], data_mesa20_3D_pert_gw[7][0::skipn],color='C3',label=r"mesa20_3D_pert",rasterized=False) #3D gw (hplus on equator) in column 8
plt.legend(handles=[line1, line2],frameon=False,labelspacing=3.5,loc=2)
ax2.get_xaxis().set_ticklabels([])
ax2.tick_params(axis='both', labelsize=12)
plt.minorticks_on()
ax2.set_ylim([-45,45])
ax2.set_xlim([xmin,xmax])
ax2.yaxis.set_ticks_position('both')

ax3 = plt.subplot(513)
line1, = plt.plot(data_mesa20_3D_pert_gw[0][0::skipn], data_mesa20_3D_pert_gw[7][0::skipn],color='C3',label=r"mesa20_3D_pert",rasterized=False) #3D gw (hplus on equator) in column 8
line2, = plt.plot(data_mesa20_3D_gw[0][0::skipn], data_mesa20_3D_gw[7][0::skipn],color='C0',label=r"mesa20_3D",rasterized=False) #3D gw (hplus on equator) in column 8
plt.legend(handles=[line1, line2],frameon=False,labelspacing=3.5,loc=2)
ax3.get_xaxis().set_ticklabels([])
ax3.tick_params(axis='both', labelsize=12)
plt.minorticks_on()
ax3.set_ylim([-4.5,4.5])
ax3.set_xlim([xmin,xmax])
ax3.yaxis.set_ticks_position('both')
ax3.set_ylabel(r"$h^\mathrm{eq}_+ \times D$ [cm]",fontsize=18)

ax4 = plt.subplot(514)
line1, = plt.plot(data_mesa20_3D_pert_LR_gw[0][0::skipn], data_mesa20_3D_pert_LR_gw[7][0::skipn],color='C6',label=r"mesa20_3D_pert_LR",rasterized=False) #3D gw (hplus on equator) in column 8
line2, = plt.plot(data_mesa20_3D_LR_gw[0][0::skipn], data_mesa20_3D_LR_gw[7][0::skipn],color='C2',label=r"mesa20_3D_LR",rasterized=False) #3D gw (hplus on equator) in column 8
plt.legend(handles=[line1, line2],frameon=False,labelspacing=3.5,loc=2)
ax4.get_xaxis().set_ticklabels([])
ax4.tick_params(axis='both', labelsize=12)
plt.minorticks_on()
ax4.set_ylim([-4.5,4.5])
ax4.set_xlim([xmin,xmax])
ax4.yaxis.set_ticks_position('both')

ax5 = plt.subplot(515)
line1, = plt.plot(data_mesa20_3D_LR_gw[0][0::skipn], data_mesa20_3D_LR_gw[7][0::skipn],color='C2',label=r"mesa20_3D_LR",rasterized=False) #3D gw (hplus on equator) in column 8
line2, = plt.plot(data_mesa20_3D_v_LR_gw[0][0::skipn], data_mesa20_3D_v_LR_gw[7][0::skipn],color='C1',label=r"mesa20_3D_v_LR",rasterized=False) #3D gw (hplus on equator) in column 8
plt.legend(handles=[line1, line2],frameon=False,labelspacing=3.5,loc=2)
plt.minorticks_on()
ax5.set_xlabel(r"$t-t_\mathrm{bounce}$ [s]",fontsize=18)
ax5.tick_params(axis='both', labelsize=12)
ax5.set_ylim([-4.5,4.5])
ax5.set_xlim([xmin,xmax])
ax5.yaxis.set_ticks_position('both')

plt.subplots_adjust(hspace=0.07)
plt.savefig("gw_trains.pdf",bbox_inches='tight')
